@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2014  Thadeu Lima de Souza Cascardo <cascardo@minaslivre.org>
+ *  Copyright (C) 2013-2017  Thadeu Lima de Souza Cascardo <cascardo@minaslivre.org>
  *  Copyright (C) 2014  Alexandre Oliva <lxoliva@fsfla.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 #include "rnet_message.h"
 #include "decfile.h"
 
-int rnet_encode(struct rnet_decfile *decfile, struct rnet_message **msg)
+int rnet_encode(struct rnet_decfile *decfile, struct rnet_message **msg, char *client)
 {
 	int r = -EIO;
 
@@ -46,6 +46,9 @@ int rnet_encode(struct rnet_decfile *decfile, struct rnet_message **msg)
 
 	size_t header_size, header_head, header_tail;
 
+	if (client == NULL)
+		client = RNET_DEFAULT_VERSION;
+
 	*msg = rnet_message_new();
 	if (*msg == NULL) {
 		return -ENOMEM;
@@ -96,7 +99,7 @@ int rnet_encode(struct rnet_decfile *decfile, struct rnet_message **msg)
 	r = rnet_message_add_ascii(msg, "versao_java", "1.5.0-gij;Free Software rnetclient pretending to be GNU Interpreter for Java");
 	r = rnet_message_add_ascii(msg, "origem", "JA2R");
 	r = rnet_message_add_ascii(msg, "so", "GNU");
-	r = rnet_message_add_ascii(msg, "cliente", "201105");
+	r = rnet_message_add_ascii(msg, "cliente", client);
 	r = rnet_message_add_buffer(msg, "dados_val",
 				    header + header_head,
 				    header_size - header_tail - header_head);
