@@ -22,6 +22,8 @@
 #include "rnet_message.h"
 #include "decfile.h"
 
-int rnet_encode(struct rnet_decfile *decfile, struct rnet_message **msg);
+#define RNET_DEFAULT_VERSION "201704"
+
+int rnet_encode(struct rnet_decfile *decfile, struct rnet_message **msg, char *client);
 
 #endif
